package com.persagy.service.impl;

import com.persagy.cache.AlarmInfoCache;
import com.persagy.entity.AlarmDefine;
import com.persagy.entity.v2.AlarmCondition;
import com.persagy.entity.v2.ObjConditionRel;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import java.util.List;

/**
 * 报警条件处理类
 *
 * @author lixing
 * @version V1.0 2021/10/25 10:06 上午
 */
@Service
public class AlarmConditionServiceImpl {
    @Autowired
    AlarmInfoCache alarmInfoCache;

   /**
    * 将报警定义缓存起来
    *
    * @param conditionList 报警定义类别
    * @author lixing
    * @version V1.0 2021/10/25 10:08 上午
    */
    public void cacheAllConditions(List<AlarmCondition> conditionList) {
        // 先清空之前缓存的条件和关联关系
        alarmInfoCache.clear();
        alarmInfoCache.cacheAlarmConditions(conditionList);
    }

    /**
     * @description:批量修改（添加）报警定义
     * （根据报警条目+对象Id先删除，再添加）
     * @exception:
     * @author: LuoGuangyi
     * @company: Persagy Technology Co.,Ltd
     * @param alarmDefineList:
     * @return: void
     * @since: 2020/10/26 20:38
     * @version: V1.0
     */
    public void listSomeAlarmDefine(List<AlarmDefine> alarmDefineList) {
        for (AlarmDefine alarmDefine : alarmDefineList) {
            alarmInfoCache.clearAlarmDefine(alarmDefine);
            alarmInfoCache.putAlarmDefinitionById(alarmDefine);
        }
    }

    /**
     * @description:根据标号功能号删除报警定义
     * @exception:
     * @author: LuoGuangyi
     * @company: Persagy Technology Co.,Ltd
     * @param alarmDefineList:
     * @return: void
     * @since: 2020/10/29 18:26
     * @version: V1.0
     */
    public void deleteAlarmDefine(List<AlarmDefine> alarmDefineList) {
        for (AlarmDefine alarmDefine : alarmDefineList) {
            alarmInfoCache.clearAlarmDefine(alarmDefine);
        }
    }

    /**
     * 缓存对象与条件的关联关系
     *
     * @param objConditionRels 对象与条件的关联关系
     * @author lixing
     * @version V1.0 2021/10/25 10:36 上午
     */
    public void cacheObjConditionRels(List<ObjConditionRel> objConditionRels) {
        if (CollectionUtils.isEmpty(objConditionRels)) {
            return;
        }
        alarmInfoCache.cacheObjConditionRels(objConditionRels);
    }
}
